@@ -7,13 +7,13 @@ try{
 catch{
   var lab = true;
 }
-console.log("Are we in JupyterLab: "+lab);
+console.log("Are we in JupyterLabssss: "+lab);
 
 var widgets = require('@jupyter-widgets/base');
 
 window.$ = window.jQuery = require( 'jquery' );
-require( 'bootstrap' );
-var dt = require( 'datatables.net' );
+var dt = require( 'datatables.net' ); 
+
 
 window.pdfMake = require('pdfmake/build/pdfmake.min');
 var vfs = require('pdfmake/build/vfs_fonts');
@@ -38,6 +38,8 @@ var _ = require('lodash');
 if(lab){
   require('fontawesome');
   require('!style-loader!css-loader!bootstrap/dist/css/bootstrap.min.css');
+  require( 'bootstrap' );
+  
 }
 
 // Load datatables styles
@@ -54,8 +56,8 @@ var InteractiveTableModel = widgets.DOMWidgetModel.extend({
         _view_name : 'InteractiveTableView',
         _model_module : 'ipydatatable',
         _view_module : 'ipydatatable',
-        _model_module_version : '0.3.0',
-        _view_module_version : '0.3.0',
+        _model_module_version : '0.3.1',
+        _view_module_version : '0.3.1',
         table : []
     })
 });
@@ -80,11 +82,13 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
       self.wrapper.id = "wrapper_"+self.cid;
       self.wrapper.style.display = "none";
       self.wrapper.style.width = '100%';
+      self.wrapper.style.setProperty('color', 'black', 'important');
       self.wrapper.style.backgroundColor="white";
 
       // Creating table element
       self.tbl = document.createElement('table');
       self.tbl.style.width = '100%';
+      self.tbl.style.setProperty('color', 'black', 'important');
       self.tbl.style.wordWrap = "break-word";
       self.tbl.id = "example_"+self.cid;
       self.tbl.className = "display";
@@ -187,6 +191,27 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
 
       // Initializing everything
       $(document).ready( function () {
+        // Code for when fullScreen goes on.
+        var calcDataTableHeight = function() {
+          return $(window).height() - 200;
+        };
+        
+        $(window).on('resize', function(){
+          if(screen.width === window.innerWidth){
+            //$('#example_'+self.cid).dataTable().fnSettings().oScroll.sY = calcDataTableHeight();
+            //$('.dataTables_scrollBody:has(#example_'+self.cid+')').height(calcDataTableHeight());  
+            $('#example_'+self.cid+'_wrapper .dataTables_scrollBody').css("height",calcDataTableHeight()+"px").css("max-height",calcDataTableHeight()+"px");
+            console.log("1");
+          }
+          else{
+            //$('#example_'+self.cid).dataTable().fnSettings().oScroll.sY = '400px';
+            //$('.dataTables_scrollBody:has(#example_'+self.cid+')').height('400px');  
+            console.log($('#example_'+self.cid+'_wrapper .dataTables_scrollBody'))
+            $('#example_'+self.cid+'_wrapper .dataTables_scrollBody').css("height",400+"px").css("max-height",400+"px");
+            console.log("2");
+          }
+        });
+
         // Add event listener for opening and closing details
         $('#example_'+self.cid+' tbody').on('click', 'td.show_details', function(){
           var column_index = table.columns().header().toArray().map(x => x.innerText)
@@ -373,7 +398,7 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
 
         // Creating table object
         var table = $('#example_'+self.cid).DataTable({
-          dom: 'Bfrtip',
+          dom: 'Blfrtip',
           buttons: [
             {
               text: 'Full Screen',
@@ -417,17 +442,19 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
             'searchBuilder','copy', 'csv', 'excel', 'pdf', 'print'
           ],
           orderCellsTop: true,
-          "autoWidth": false,
+          //"autoWidth": false,
           order: [[ sort_col , "desc" ]],
           "lengthMenu": [[10, 25, 50, 100, 500, -1], [10, 25, 50, 100, 500, "All"]],
           fixedHeader: true,
           scrollY: 400,
+          scrollResize: true,
+          "scrollCollapse": true,
           scrollX: true,
           select:{
             style: 'multi'
           },
           colReorder: true,
-          responsive:true,
+          //responsive:true,
           columnDefs: [ 
             { width: 10, targets: 0, orderable: false, className:"notToggleVis" },
             { targets: hide_cols, visible: false },
@@ -470,6 +497,7 @@ var InteractiveTableView = widgets.DOMWidgetView.extend({
         // Only for JupyterLab to make table not be gigantic.
         if(lab){
           self.wrapper.style.width = (document.getElementById("wrapper_"+self.cid).parentNode.parentNode.parentNode.parentElement.clientWidth-100)+"px";
+          self.wrapper.style.setProperty('color', 'black', 'important');
         }        
         table.columns.adjust();
       } );
